@@ -92,10 +92,10 @@ class MethodHasher(object):
         # to change hashes for all customers -> meaning, quality risks
         try:
             code = astunparse.unparse(node)
-            copied_node = ast_utils.parse(code)
+            copied_node = ast.parse(code)
             return copied_node
         except SyntaxError as e:
             log.warning("coping node using astor")
             code = astor.to_source(node)
-            copied_node = ast_utils.parse(code)
+            copied_node = ast.parse(code)
             return copied_node
