@@ -1,17 +1,14 @@
 import json
 import logging
-import time
 
+from python_agent import __package_name__ as PACKAGE_NAME
+from python_agent import __version__ as VERSION
 from python_agent.common.build_session.build_session_data import BuildSessionData
 from python_agent.common.http.requests_wrapper import Requests
 from python_agent.common.http.sl_routes import SLRoutes
 from python_agent.packages import requests
-from python_agent import __package_name__ as PACKAGE_NAME
-from python_agent import __version__ as VERSION
 from python_agent.packages.requests import HTTPError
 
-from python_agent.common.constants import TEST_RECOMMENDATION
-
 log = logging.getLogger(__name__)
 
 
@@ -144,39 +141,6 @@ class BackendProxy(object):
 
         return {}
 
-    def get_recommendations(self, config_data):
-        interval_sec = config_data.testSelection["interval"]
-        timeout_sec = config_data.testSelection["timeout"]
-        test_recommendations = {
-            "testSelectionEnabled": False,
-            "recommendedTests": [],
-            "excludedTests": []
-        }
-        if (config_data.testSelection["enable"]):
-            if (interval_sec < 0):
-                interval_sec = TEST_RECOMMENDATION.interval_sec
-            if (timeout_sec < 0):
-                timeout_sec = TEST_RECOMMENDATION.timeout_sec
-            if (timeout_sec == 0 or interval_sec == 0):
-                test_recommendations = self.try_get_recommendations(config_data.buildSessionId) or dict()
-                return test_recommendations
-            
-            n_retry = 0
-            while timeout_sec > 0:
-                test_recommendations = self.try_get_recommendations(config_data.buildSessionId) or dict()
-                if not (self.is_selection_enabled_and_not_ready(test_recommendations)):
-                    return test_recommendations
-                n_retry += 1
-                time.sleep(interval_sec)
-                timeout_sec -= interval_sec
-                log.debug("Failed to receive test recommendations. remain %d retry" % (timeout_sec / interval_sec))
-            else:
-                log.warning("did not get test recommendations after %d tries and %d seconds" % (n_retry, timeout_sec))
-                return test_recommendations
-        else:
-            log.warning("Test recommendations disabled")
-            return test_recommendations
-
     def try_get_recommendations(self, build_session_id):
         url = SLRoutes.test_exclusions_v3(build_session_id, self.config_data.testStage)
         try:
@@ -188,11 +152,6 @@ class BackendProxy(object):
             log.warning("failed get recommendation tests from server URL: %s. Error: %s" % (url, str(e)))
             return {}
 
-    def is_selection_enabled_and_not_ready(self, test_recommendations):
-        return test_recommendations.get(TEST_RECOMMENDATION.TEST_SELECTION_ENABLED) and\
-               test_recommendations.get(TEST_RECOMMENDATION.RSS) and\
-               test_recommendations[TEST_RECOMMENDATION.RSS].lower() == TEST_RECOMMENDATION.RSS_NOT_READY
-
     def get_build_session_from_labid(self, labid):
         url = SLRoutes.lab_ids_active_build_session_v1(labid)
         try:
