@@ -11,6 +11,7 @@ from python_agent.test_listener.integrations.freezegun_patcher import FreezeGunP
 from python_agent.test_listener.integrations.pytest_xdist_helper import override_xdist_exit_timeout
 from python_agent.test_listener.managers.events_manager import EventsManager
 from python_agent.test_listener.managers.footprints_manager import FootprintsManager
+from python_agent.test_listener.managers.tia_manager import TIAManager
 from python_agent.test_listener.state_tracker import StateTracker
 from python_agent.test_listener.utils import Singleton
 
@@ -19,16 +20,18 @@ log = logging.getLogger(__name__)
 @add_metaclass(Singleton)
 class AgentManager(object):
 
-    def __init__(self, config_data=None):
-        log.info("Initializing...")
+    def __init__(self, config_data=None, is_master=True):
+        log.info("Initializing... Is Master? %s" % is_master)
         if not config_data:
             raise Exception("'config_data' must be provided")
         self.config_data = config_data
+        self.is_master = is_master
         self.pid = os.getpid()
         self.backend_proxy = BackendProxy(config_data)
         self.state_tracker = StateTracker(config_data)
         self.footprints_manager = FootprintsManager(config_data, self.backend_proxy)
         self.events_manager = EventsManager(config_data, self.backend_proxy)
+        self.tia_manager = TIAManager(config_data)
         self.footprints_manager.start()
         self.events_manager.start()
         atexit.register(self.shutdown)
@@ -37,12 +40,7 @@ class AgentManager(object):
         # self.register_uwsgi_at_exit()
 
     def get_excluded_tests(self):
-        test_recommendations = self.backend_proxy.get_recommendations(self.config_data)
-        if (self.config_data.testSelection["enable"] and
-                test_recommendations.get('testSelectionEnabled', False) and
-                len(test_recommendations.get('excludedTests', [])) > 0):
-            return test_recommendations.get('excludedTests', [])
-        return []
+        return self.tia_manager.get_excluded_tests()
 
     def create_execution_id(self):
         return str(uuid.uuid4())
@@ -58,7 +56,7 @@ class AgentManager(object):
     def shutdown(self):
         if self.pid == os.getpid():
             self.events_manager.shutdown()
-            self.footprints_manager.shutdown()
+            self.footprints_manager.shutdown(self.is_master)
             log.info("Finished Shutting Down Agent Manager")
 
     def get_trace_function(self):
