@@ -1,16 +1,14 @@
 import logging
 import threading
 
-from apscheduler.executors.pool import ProcessPoolExecutor
-from apscheduler.schedulers.background import BackgroundScheduler
-
 from python_agent.common import constants
-from python_agent.packages import interval
 from python_agent.packages.blinker import signal
 from python_agent.test_listener.queues.events_queue import EventsQueue
 from python_agent.test_listener.services.events_service import EventsService
 
-
+from apscheduler.triggers import interval
+from apscheduler.executors.pool import ProcessPoolExecutor
+from apscheduler.schedulers.background import BackgroundScheduler
 scheduler_class = BackgroundScheduler
 kwargs = {
     "executors": {'processpool': ProcessPoolExecutor(1)}
@@ -25,7 +23,7 @@ class EventsManager(object):
         self.events_service = EventsService(config_data, backend_proxy)
         self.events_queue = EventsQueue(maxsize=constants.MAX_ITEMS_IN_QUEUE)
         self.watchdog = scheduler_class(**kwargs)
-        self.watchdog.add_job(self.send_all, interval.IntervalTrigger(milliseconds=self.config_data.interval))
+        self.watchdog.add_job(self.send_all, interval.IntervalTrigger(seconds=self.config_data.intervalSeconds))
         self._is_sending_lock = threading.Lock()
 
     def push_event(self, event):
